@@ -235,6 +235,8 @@ def grep_for_pdb(c, exclude=None):
     """
     if exclude is None:
         exclude = []
+    elif isinstance(exclude, str):
+        exclude = exclude.split(',')
     exclude += ['fabfile.py']
     exclusions = ' '.join(["-path './{}' -prune -o".format(ex) for ex in exclude])
     c.local("! find {exclusions} -name '*.py' -exec grep -n '\\bpdb\\b' {{}} +".format(exclusions=exclusions))
@@ -250,7 +252,7 @@ def check_site_online(c):
     # TODO: Is there a better way to make invoke fail loudly?
     try:
         c.run('curl --silent --head {c.env.url} | grep --perl-regexp "^HTTP/.+ 200"'.format(c=c))
-    except invoke.UnexpectedExit as c:
+    except invoke.UnexpectedExit:
         raise invoke.Exit('Site check failed!')
 
 
@@ -259,14 +261,14 @@ def install_scheduled_jobs(c, periodic_jobs=None, crontabs=None):
     crontabs = [] if crontabs is None else crontabs
 
     typical_periodic_jobs = {
-        'deploy/cron.hourly',
-        'deploy/cron.daily',
-        'deploy/cron.weekly',
-        'deploy/cron.monthly',
+        'cron.hourly',
+        'cron.daily',
+        'cron.weekly',
+        'cron.monthly',
     }
     for job in periodic_jobs:
-        if job in typical_periodic_jobs:
-            basename = os.path.basename(job)
+        basename = os.path.basename(job)
+        if basename in typical_periodic_jobs:
             _sudo_upload_template(
                 c,
                 job,
